==> cayenne-4.0.3-src.tar.gz: cayenne-4.0.3-src/cayenne-server/src/main/java/org/apache/cayenne/access/ToManySet.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.access;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

import org.apache.cayenne.PersistenceState;
import org.apache.cayenne.Persistent;
import org.apache.cayenne.util.PersistentObjectSet;

public class ToManySet extends PersistentObjectSet implements Serializable {

    protected ToManySet(Persistent relationshipOwner, String relationshipName) {
        super(relationshipOwner, relationshipName);
    }

    @Override
    protected boolean shouldAddToRemovedFromUnresolvedSet(Object object) {
        // No point in adding a new or transient object -- these will never be fetched
        // from the database.
        if (object instanceof Persistent) {
            Persistent dataObject = (Persistent) object;
            return (dataObject.getPersistenceState() != PersistenceState.TRANSIENT)
                    && (dataObject.getPersistenceState() != PersistenceState.NEW);
        }
        return true;
    }

    @Override
    protected void postprocessAdd(Collection<?> collection) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessRemove(Collection<?> collection) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessAdd(Object addedObject) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessRemove(Object removedObject) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void updateReverse(List resolved) {
        // no need for this operation for DataObjects...
    }

}

==> cayenne-4.1.1-src.tar.gz: cayenne-4.1.1-src/cayenne-server/src/main/java/org/apache/cayenne/access/ToManySet.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.access;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

import org.apache.cayenne.PersistenceState;
import org.apache.cayenne.Persistent;
import org.apache.cayenne.util.PersistentObjectSet;

public class ToManySet<E> extends PersistentObjectSet<E> implements Serializable {

    protected ToManySet(Persistent relationshipOwner, String relationshipName) {
        super(relationshipOwner, relationshipName);
    }

    @Override
    protected boolean shouldAddToRemovedFromUnresolvedSet(E object) {
        // No point in adding a new or transient object -- these will never be fetched
        // from the database.
        if (object instanceof Persistent) {
            Persistent dataObject = (Persistent) object;
            return (dataObject.getPersistenceState() != PersistenceState.TRANSIENT)
                    && (dataObject.getPersistenceState() != PersistenceState.NEW);
        }
        return true;
    }

    @Override
    protected void postprocessAdd(Collection<? extends E> collection) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessRemove(Collection<? extends E> collection) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessAdd(E addedObject) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void postprocessRemove(E removedObject) {
        // no need for this operation for DataObjects...
    }

    @Override
    protected void updateReverse(List<E> resolved) {
        // no need for this operation for DataObjects...
    }
}
